using System;
using System.Collections.Generic;
using System.Text;
using CG67.FicheCollege.Domaine;
using CG67.FicheCollege.Interface;

namespace CG67.FicheCollege.Entrepot
{
    public static class EntrepotFactory
    {
        private static IEntrepotActionEducative entrepotActionEducative;
        public static IEntrepotActionEducative GetEntrepotActionEducative()
        {
            if (entrepotActionEducative == null)
                entrepotActionEducative = new EntrepotActionEducative();
            return entrepotActionEducative;
        }


        private static IEntrepotClasseDecouverte entrepotClasseDecouverte;
        public static IEntrepotClasseDecouverte GetEntrepotClasseDecouverte()
         {
            if (entrepotClasseDecouverte == null)
                entrepotClasseDecouverte = new EntrepotClasseDecouverte();
            return entrepotClasseDecouverte;
        }

        private static IEntrepotATC entrepotATC;
        public static IEntrepotATC GetEntrepotATC()
        {
            if (entrepotATC == null)
                entrepotATC = new EntrepotATC();
            return entrepotATC;
        }

        private static  IEntrepotContratAide entrepotContratAide;
        public static IEntrepotContratAide GetEntrepotContratAide()
        {
            if (entrepotContratAide == null)
                entrepotContratAide = new EntrepotContratAide();
            return entrepotContratAide;
        }


        private static IEntrepotBilinguisme entrepotBilinguisme;
        public static IEntrepotBilinguisme GetEntrepotBilinguisme()
        {
            if (entrepotBilinguisme == null)
                entrepotBilinguisme = new EntrepotBilinguisme();
            return entrepotBilinguisme;
        }

        private static IEntrepotDotation entrepotDotation;
        public static IEntrepotDotation GetEntrepotDotation()
        {
            if (entrepotDotation == null)
                entrepotDotation = new EntrepotDotation();
            return entrepotDotation;
        }

        private static IEntrepotInvestissementDCE entrepotEquipement;
        public static IEntrepotInvestissementDCE GetEntrepotEquipement()
        {
            if (entrepotEquipement == null)
                entrepotEquipement = new EntrepotInvestissementDCE();
            return entrepotEquipement;
        }

        private static IEntrepotInvestissement entrepotInvestissement;
        public static IEntrepotInvestissement GetEntrepotInvestissement()
        {
            if (entrepotInvestissement == null)
                entrepotInvestissement = new EntrepotInvestissement();
            return entrepotInvestissement;
        }

        private static IEntrepotEffectifDetail entrepotEffectifDetail;
        public static IEntrepotEffectifDetail GetEntrepotEffectifDetail()
        {
            if (entrepotEffectifDetail == null)
                entrepotEffectifDetail = new EntrepotEffectifDetail();
            return entrepotEffectifDetail;
        }


        private static IEntrepotLogement entrepotLogement;
        public static IEntrepotLogement GetEntrepotLogement()
        {
            if (entrepotLogement == null)
                entrepotLogement = new EntrepotLogement();
            return entrepotLogement;
        }

        private static IEntrepotMCG entrepotMCG;
        public static IEntrepotMCG GetEntrepotMCG()
        {
            if (entrepotMCG == null)
                entrepotMCG = new EntrepotMCG();
            return entrepotMCG;
        }

        private static IEntrepotProjetPilote entrepotProjetPilote;
        public static IEntrepotProjetPilote GetEntrepotProjetPilote()
        {
            if (entrepotProjetPilote == null)
                entrepotProjetPilote = new EntrepotProjetPilote();
            return entrepotProjetPilote;
        }

        private static IEntrepotRestaurationExterne entrepotRestaurationExterne;
        public static IEntrepotRestaurationExterne GetEntrepotRestaurationExterne()
        {
            if (entrepotRestaurationExterne == null)
                entrepotRestaurationExterne = new EntrepotRestaurationExterne();
            return entrepotRestaurationExterne;
        }

        private static IEntrepotContact entrepotContact;
        public static IEntrepotContact GetEntrepotContact()
        {
            if (entrepotContact == null)
                entrepotContact = new EntrepotContact();
            return entrepotContact;
        }

        private static IEntrepotChiffresSignificatifs entrepotChiffresSignificatifs;
        public static IEntrepotChiffresSignificatifs GetEntrepotChiffresSignificatifs()
        {
            if (entrepotChiffresSignificatifs == null)
                entrepotChiffresSignificatifs = new EntrepotChiffresSignificatifs();
            return entrepotChiffresSignificatifs;
        }

        private static IEntrepotCommentaires entrepotCommentaires;
        public static IEntrepotCommentaires GetEntrepotCommentaires()
        {
            if (entrepotCommentaires == null)
                entrepotCommentaires = new EntrepotCommentaires();
            return entrepotCommentaires;
        }

        private static IEntrepotRestauration entrepotRestauration;
        public static IEntrepotRestauration GetEntrepotRestauration()
        {
            if (entrepotRestauration == null)
                entrepotRestauration = new EntrepotRestauration();
            return entrepotRestauration;
        }

        private static IEntrepotSoutienScolaireEnLigne entrepotSoutienScolaireEnLigne;
        public static IEntrepotSoutienScolaireEnLigne GetEntrepotSoutienScolaireEnLigne()
        {
            if (entrepotSoutienScolaireEnLigne == null)
                entrepotSoutienScolaireEnLigne = new EntrepotSoutienScolaireEnLigne();
            return entrepotSoutienScolaireEnLigne;
        }

        private static IEntrepotProgTravaux entrepotProgTravaux;
        public static IEntrepotProgTravaux GetEntrepotProgTravaux()
        {
            if (entrepotProgTravaux == null)
                entrepotProgTravaux = new EntrepotProgTravaux();
            return entrepotProgTravaux;
        }

   

        private static IEntrepotEtablissement entrepotEtablissement;
        public static IEntrepotEtablissement GetEntrepotEtablissement()
        {
            if (entrepotEtablissement == null)
                entrepotEtablissement = new EntrepotEtablissement();
            return entrepotEtablissement;
        }

    }
}
